#!/bin/bash
# Script 1 - Download data from the Sequence Read Archive (SRA)

# Customize number of threads to use for fastqc
NUM_THREADS=8

# This script requires an accession list from the SRA to be present in the root 
# of the project directory (obtained by extracting the project archive).

# Loop over the accession list, downloading each file as a FastQ.gz file. This 
#script is for downloading paired-end data so two files for each sample will be 
# downloaded.
while read -r acc
do
  # Ignore empty lines
  [ -z "$acc" ] && continue

  echo "Downloading $acc"
  if ! fastq-dump --gzip --skip-technical --readids --read-filter pass \
       --dumpbase --split-3 --clip --outdir data "$acc"
  then
      echo "Error downloading $acc"
  fi
done < SRR_Acc_List.txt

# Determine quality of reads using FastQC
find data -name '*.fastq.gz' -print0 | xargs -0 ./programs/fastqc -t "$NUM_THREADS"
