#!/bin/bash
# Script 2 - Quantification of reads using Kallisto

# This script requires an unzipped cDNA reference transcriptome for humans to 
# be present in the root directory of the project folder. This can be obtained
# from Ensembl (see README). Additionally, Script 1 must have been run so that
# the sample .FastQ.gz files are present in the directory "data".

# Customize number of threads to use for kallisto
NUM_THREADS=8

# Build index from reference transcriptome using Kallisto
./programs/kallisto index -i Homo_sapiens.GRCh38.cdna.all.index Homo_sapiens.GRCh38.cdna.all.fa

# Perform paired-end read mapping using Kallisto
# 50 bootstraps are performed for each sample. Multithreading is utilized if
# available. For each sample a log is stored in the directory "logs". These logs 
# contain information about the mapping including the percentage of reads that
# were mapped.

# Read mapping of control samples (latent infection)
for thing in ERR3458961 ERR3458959 ERR3458957 ERR3458955
do
    ./programs/kallisto quant -i Homo_sapiens.GRCh38.cdna.all.index \
               -o results/"$thing" -b 50 -t "$NUM_THREADS" \
               data/"$thing"_pass_1.fastq.gz data/"$thing"_pass_2.fastq.gz \
               > logs/"$thing".log 2>&1
done

# Read mapping of experimental samples (active infection)
for thing in ERR3458939 ERR3458941 ERR3458943 ERR3458951
do
    ./programs/kallisto quant -i Homo_sapiens.GRCh38.cdna.all.index \
               -o results/"$thing" -b 50 -t "$NUM_THREADS" \
               data/"$thing"_pass_1.fastq.gz data/"$thing"_pass_2.fastq.gz \
               > logs/"$thing".log 2>&1
done
